@@ -45,10 +45,7 @@ class OCSPResponder(object):
 
     def __del__(self):
         self.stop_responder()
-        if os.path.exists(self.crl_file_path):
-            os.remove(self.crl_file_path)
-        if os.path.exists(self.crl_file_path + ATTRIBUTE_FILE_SUFFIX):
-            os.remove(self.crl_file_path + ATTRIBUTE_FILE_SUFFIX)
+        self.delete_crl_file()
 
     def start_responder(self):
         """
@@ -68,7 +65,6 @@ class OCSPResponder(object):
                 '-CA', self.ca_certificate_path]
         if self.log_path is not None:
             args += ['-text', '-out', self.log_path]
-        print(args)
 
         self.responder_process = subprocess.Popen(args=args,
                                                   stdout=subprocess.PIPE,
@@ -88,18 +84,19 @@ class OCSPResponder(object):
         self.stop_responder()
         self.start_responder()
 
+    def delete_crl_file(self):
+        if os.path.exists(self.crl_file_path):
+            os.remove(self.crl_file_path)
+        if os.path.exists(self.crl_file_path + ATTRIBUTE_FILE_SUFFIX):
+            os.remove(self.crl_file_path + ATTRIBUTE_FILE_SUFFIX)
+
     def write_crl(self):
         """
         Creates the CRL file for the OpenSSL OCSP Responder
         """
+        self.delete_crl_file()
         with open(self.crl_file_path, 'w') as crl_file:
             for cert in self.crl.values():
-                print("{}\t{}\t{}\t{}\t{}\t{}\n".format(cert['status'],
-                                                                      cert['expiration_time'],
-                                                                      cert['revocation_time'],
-                                                                      cert['serial_number'],
-                                                                      'unknown',
-                                                                      cert['subject']))
                 crl_file.write("{}\t{}\t{}\t{}\t{}\t{}\n".format(cert['status'],
                                                                       cert['expiration_time'],
                                                                       cert['revocation_time'],
